==> ubuntu_localizations-0.1.3.tar.gz: lib/src/l10n/ubuntu_localizations_de.dart <==
import 'ubuntu_localizations.dart';

/// The translations for German (`de`).
class UbuntuLocalizationsDe extends UbuntuLocalizations {
  UbuntuLocalizationsDe([String locale = 'de']) : super(locale);

  @override
  String get countryCode => 'DE';

  @override
  String get languageName => 'Deutsch';

  @override
  String get backAction => 'Zurück';

  @override
  String get continueAction => 'Weiter';

  @override
  String get strongPassword => 'Starkes Passwort';

  @override
  String get fairPassword => 'Ausreichendes Passwort';

  @override
  String get goodPassword => 'Gutes Passwort';

  @override
  String get weakPassword => 'Schwaches Passwort';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Strg';

  @override
  String get metaKey => 'Meta';

  @override
  String get shiftKey => 'Umschalt';

  @override
  String get aboutLabel => 'Über';

  @override
  String get addLabel => 'Hinzufügen';

  @override
  String get allLabel => 'Alle';

  @override
  String get applyLabel => 'Anwenden';

  @override
  String get ascendingLabel => 'Aufsteigend';

  @override
  String get backLabel => 'Zurück';

  @override
  String get boldLabel => 'Fett';

  @override
  String get bottomLabel => 'Unten';

  @override
  String get cancelLabel => 'Abbrechen';

  @override
  String get centerLabel => 'Mitte';

  @override
  String get clearLabel => 'Leeren';

  @override
  String get closeLabel => 'Schließen';

  @override
  String get colorLabel => 'Farbe';

  @override
  String get connectLabel => 'Verbinden';

  @override
  String get continueLabel => 'Weiter';

  @override
  String get copyLabel => 'Kopieren';

  @override
  String get createLabel => 'Erstellen';

  @override
  String get cutLabel => 'Ausschneiden';

  @override
  String get decreaseLabel => 'Verringern';

  @override
  String get deleteLabel => 'Löschen';

  @override
  String get descendingLabel => 'Absteigend';

  @override
  String get discardLabel => 'Verwerfen';

  @override
  String get disconnectLabel => 'Trennen';

  @override
  String get doneLabel => 'Fertig';

  @override
  String get downloadLabel => 'Herunterladen';

  @override
  String get editLabel => 'Bearbeiten';

  @override
  String get enterLabel => 'Eingabe';

  @override
  String get errorLabel => 'Fehler';

  @override
  String get executeLabel => 'Ausführen';

  @override
  String get exitLabel => 'Beenden';

  @override
  String get fileLabel => 'Datei';

  @override
  String get fillLabel => 'Füllen';

  @override
  String get findLabel => 'Suchen';

  @override
  String get firstLabel => 'Erste';

  @override
  String get fontLabel => 'Schriftart';

  @override
  String get forwardLabel => 'Vorwärts';

  @override
  String get fullscreenLabel => 'Vollbild';

  @override
  String get goBackLabel => 'Zurück';

  @override
  String get helpLabel => 'Hilfe';

  @override
  String get homeLabel => 'Zuhause';

  @override
  String get importLabel => 'Importieren';

  @override
  String get increaseLabel => 'Erhöhen';

  @override
  String get indexLabel => 'Index';

  @override
  String get informationLabel => 'Information';

  @override
  String get insertLabel => 'Einfügen';

  @override
  String get italicLabel => 'Kursiv';

  @override
  String get landscapeLabel => 'Querformat';

  @override
  String get lastLabel => 'Letzte';

  @override
  String get leaveLabel => 'Verlassen';

  @override
  String get leftLabel => 'Links';

  @override
  String get mediaLabel => 'Medien';

  @override
  String get networkLabel => 'Netzwerk';

  @override
  String get newLabel => 'Neu';

  @override
  String get nextLabel => 'Nächste';

  @override
  String get noLabel => 'Nein';

  @override
  String get noneLabel => 'Kein';

  @override
  String get normalLabel => 'Normal';

  @override
  String get okLabel => 'OK';

  @override
  String get openLabel => 'Öffnen';

  @override
  String get pasteLabel => 'Einfügen';

  @override
  String get pauseLabel => 'Pausieren';

  @override
  String get playLabel => 'Abspielen';

  @override
  String get portraitLabel => 'Hochformat';

  @override
  String get preferencesLabel => 'Einstellungen';

  @override
  String get previousLabel => 'Vorherige';

  @override
  String get printLabel => 'Drucken';

  @override
  String get printPreviewLabel => 'Druckvorschau';

  @override
  String get propertiesLabel => 'Eigenschaften';

  @override
  String get questionLabel => 'Frage';

  @override
  String get quitLabel => 'Beenden';

  @override
  String get recordLabel => 'Record';

  @override
  String get redoLabel => 'Rückgängig';

  @override
  String get refreshLabel => 'Aktualisieren';

  @override
  String get removeLabel => 'Entfernen';

  @override
  String get renameLabel => 'Umbenennen';

  @override
  String get resetLabel => 'Zurücksetzen';

  @override
  String get restoreLabel => 'Wiederherstellen';

  @override
  String get retryLabel => 'Wiederholen';

  @override
  String get revertLabel => 'Zurücksetzen';

  @override
  String get rewindLabel => 'Zurückspulen';

  @override
  String get rightLabel => 'Rechts';

  @override
  String get saveAsLabel => 'Speichern unter';

  @override
  String get saveLabel => 'Speichern';

  @override
  String get searchLabel => 'Suchen';

  @override
  String get selectAllLabel => 'Alles auswählen';

  @override
  String get selectLabel => 'Auswählen';

  @override
  String get sendLabel => 'Senden';

  @override
  String get skipLabel => 'Überspringen';

  @override
  String get sortLabel => 'Sortieren';

  @override
  String get stopLabel => 'Anhalten';

  @override
  String get strikeThroughLabel => 'Durchstreichen';

  @override
  String get submitLabel => 'Absenden';

  @override
  String get topLabel => 'Top';

  @override
  String get undoLabel => 'Rückgängig';

  @override
  String get updateLabel => 'Update';

  @override
  String get upLabel => 'Up';

  @override
  String get viewLabel => 'Ansicht';

  @override
  String get warningLabel => 'Warnung';

  @override
  String get windowLabel => 'Fenster';

  @override
  String get yesLabel => 'Ja';

  @override
  String get zoomInLabel => 'Heranzoomen';

  @override
  String get zoomOutLabel => 'Herauszoomen';
}

==> ubuntu_localizations-0.1.6.tar.gz: lib/src/l10n/ubuntu_localizations_de.dart <==
import 'ubuntu_localizations.dart';

/// The translations for German (`de`).
class UbuntuLocalizationsDe extends UbuntuLocalizations {
  UbuntuLocalizationsDe([String locale = 'de']) : super(locale);

  @override
  String get countryCode => 'DE';

  @override
  String get languageName => 'Deutsch';

  @override
  String get backAction => 'Zurück';

  @override
  String get continueAction => 'Weiter';

  @override
  String get strongPassword => 'Starkes Passwort';

  @override
  String get fairPassword => 'Ausreichendes Passwort';

  @override
  String get goodPassword => 'Gutes Passwort';

  @override
  String get weakPassword => 'Schwaches Passwort';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Strg';

  @override
  String get metaKey => 'Meta';

  @override
  String get shiftKey => 'Umschalt';

  @override
  String get aboutLabel => 'Über';

  @override
  String get addLabel => 'Hinzufügen';

  @override
  String get allLabel => 'Alle';

  @override
  String get applyLabel => 'Anwenden';

  @override
  String get ascendingLabel => 'Aufsteigend';

  @override
  String get backLabel => 'Zurück';

  @override
  String get boldLabel => 'Fett';

  @override
  String get bottomLabel => 'Unten';

  @override
  String get cancelLabel => 'Abbrechen';

  @override
  String get centerLabel => 'Mitte';

  @override
  String get clearLabel => 'Leeren';

  @override
  String get closeLabel => 'Schließen';

  @override
  String get colorLabel => 'Farbe';

  @override
  String get connectLabel => 'Verbinden';

  @override
  String get continueLabel => 'Weiter';

  @override
  String get copyLabel => 'Kopieren';

  @override
  String get createLabel => 'Erstellen';

  @override
  String get cutLabel => 'Ausschneiden';

  @override
  String get decreaseLabel => 'Verringern';

  @override
  String get deleteLabel => 'Löschen';

  @override
  String get descendingLabel => 'Absteigend';

  @override
  String get discardLabel => 'Verwerfen';

  @override
  String get disconnectLabel => 'Trennen';

  @override
  String get doneLabel => 'Fertig';

  @override
  String get downloadLabel => 'Herunterladen';

  @override
  String get editLabel => 'Bearbeiten';

  @override
  String get enterLabel => 'Eingabe';

  @override
  String get errorLabel => 'Fehler';

  @override
  String get executeLabel => 'Ausführen';

  @override
  String get exitLabel => 'Beenden';

  @override
  String get fileLabel => 'Datei';

  @override
  String get fillLabel => 'Füllen';

  @override
  String get findLabel => 'Suchen';

  @override
  String get firstLabel => 'Erste';

  @override
  String get fontLabel => 'Schriftart';

  @override
  String get forwardLabel => 'Weiter';

  @override
  String get fullscreenLabel => 'Vollbild';

  @override
  String get goBackLabel => 'Zurück';

  @override
  String get helpLabel => 'Hilfe';

  @override
  String get homeLabel => 'Zuhause';

  @override
  String get importLabel => 'Importieren';

  @override
  String get increaseLabel => 'Erhöhen';

  @override
  String get indexLabel => 'Index';

  @override
  String get informationLabel => 'Information';

  @override
  String get insertLabel => 'Einfügen';

  @override
  String get italicLabel => 'Kursiv';

  @override
  String get landscapeLabel => 'Querformat';

  @override
  String get lastLabel => 'Letzte';

  @override
  String get leaveLabel => 'Verlassen';

  @override
  String get leftLabel => 'Links';

  @override
  String get mediaLabel => 'Medien';

  @override
  String get networkLabel => 'Netzwerk';

  @override
  String get newLabel => 'Neu';

  @override
  String get nextLabel => 'Weiter';

  @override
  String get noLabel => 'Nein';

  @override
  String get noneLabel => 'Kein';

  @override
  String get normalLabel => 'Normal';

  @override
  String get okLabel => 'OK';

  @override
  String get openLabel => 'Öffnen';

  @override
  String get pasteLabel => 'Einfügen';

  @override
  String get pauseLabel => 'Pausieren';

  @override
  String get playLabel => 'Abspielen';

  @override
  String get portraitLabel => 'Hochformat';

  @override
  String get preferencesLabel => 'Einstellungen';

  @override
  String get previousLabel => 'Zurück';

  @override
  String get printLabel => 'Drucken';

  @override
  String get printPreviewLabel => 'Druckvorschau';

  @override
  String get propertiesLabel => 'Eigenschaften';

  @override
  String get questionLabel => 'Frage';

  @override
  String get quitLabel => 'Beenden';

  @override
  String get recordLabel => 'Aufnehmen';

  @override
  String get redoLabel => 'Rückgängig';

  @override
  String get refreshLabel => 'Auffrischen';

  @override
  String get removeLabel => 'Entfernen';

  @override
  String get renameLabel => 'Umbenennen';

  @override
  String get resetLabel => 'Zurücksetzen';

  @override
  String get restoreLabel => 'Wiederherstellen';

  @override
  String get retryLabel => 'Wiederholen';

  @override
  String get revertLabel => 'Zurücksetzen';

  @override
  String get rewindLabel => 'Zurückspulen';

  @override
  String get rightLabel => 'Rechts';

  @override
  String get saveAsLabel => 'Speichern unter';

  @override
  String get saveLabel => 'Speichern';

  @override
  String get searchLabel => 'Suchen';

  @override
  String get selectAllLabel => 'Alles auswählen';

  @override
  String get selectLabel => 'Auswählen';

  @override
  String get sendLabel => 'Senden';

  @override
  String get skipLabel => 'Überspringen';

  @override
  String get sortLabel => 'Sortieren';

  @override
  String get stopLabel => 'Anhalten';

  @override
  String get strikeThroughLabel => 'Durchstreichen';

  @override
  String get submitLabel => 'Absenden';

  @override
  String get topLabel => 'Oben';

  @override
  String get undoLabel => 'Rückgängig';

  @override
  String get updateLabel => 'Aktualisieren';

  @override
  String get upLabel => 'Nach oben';

  @override
  String get viewLabel => 'Ansicht';

  @override
  String get warningLabel => 'Warnung';

  @override
  String get windowLabel => 'Fenster';

  @override
  String get yesLabel => 'Ja';

  @override
  String get zoomInLabel => 'Heranzoomen';

  @override
  String get zoomOutLabel => 'Herauszoomen';
}
